@@ -7,7 +7,7 @@ mode of execution and interaction.
 
 #If you change the version here, make sure to also change it in setup.py and
 #the module __init__.py
-__version__ = '0.3.2'
+__version__ = '0.3.5'
 
 #Standard Library Modules
 import argparse
@@ -25,6 +25,7 @@ from openaccess_epub.utils.images import get_images
 import openaccess_epub.opf as opf
 import openaccess_epub.ncx as ncx
 import openaccess_epub.ops as ops
+from openaccess_epub.article import Article as Article
 
 CACHE_LOCATION = utils.cache_location()
 LOCAL_DIR = os.getcwd()
@@ -103,17 +104,20 @@ def single_input(args, config):
     """
     #Determination of input type and processing
     #Fetch by URL
-    if 'http://www' in args.input:
+    if 'http:' in args.input:
+        raw_name = u_input.url_input(args.input)
         abs_input_path = os.path.join(LOCAL_DIR, raw_name+'.xml')
-        parsed_article, raw_name = u_input.url_input(args.input)
+        parsed_article = Article(abs_input_path)
     #Fetch by DOI
     elif args.input[:4] == 'doi:':
+        raw_name = u_input.doi_input(args.input)
         abs_input_path = os.path.join(LOCAL_DIR, raw_name+'.xml')
-        parsed_article, raw_name = u_input.doi_input(args.input)
+        parsed_article = Article(abs_input_path)
     #Local XML input
     else:
         abs_input_path = utils.get_absolute_path(args.input)
-        parsed_article, raw_name = u_input.local_input(abs_input_path)
+        raw_name = u_input.local_input(abs_input_path)
+        parsed_article = Article(abs_input_path)
 
     #Generate the output path name, this will be the directory name for the
     #output. This output directory will later be zipped into an EPUB
@@ -121,9 +125,10 @@ def single_input(args, config):
 
     #Make the EPUB
     make_epub(parsed_article,
-              output_name,
-              args.images,   # Path specifying where to find the images
-              batch=False)
+              outdirect=output_name,
+              explicit_images=args.images,   # Explicit image path
+              batch=False,
+              config=config)
 
     #Cleanup removes the produced output directory, keeps the ePub file
     if args.clean:  # Defaults to False, --clean or -c to toggle on
@@ -132,7 +137,7 @@ def single_input(args, config):
     #Running epubcheck on the output verifies the validity of the ePub,
     #requires a local installation of java and epubcheck.
     if args.no_epubcheck:
-        epubcheck('{0}.epub'.format(output_name))
+        epubcheck('{0}.epub'.format(output_name), config)
 
 
 def batch_input(args, config):
@@ -166,9 +171,11 @@ def batch_input(args, config):
 
         #Parse the article
         try:
-            parsed_article, raw_name = u_input.local_input(item_path)
+            raw_name = u_input.local_input(item_path)
         except:
             traceback.print_exc(file=error_file)
+        else:
+            parsed_article = Article(os.path.join(args.batch, raw_name+'.xml'))
 
         #Create the output name
         output_name = os.path.join(utils.get_output_directory(args), raw_name)
@@ -176,9 +183,10 @@ def batch_input(args, config):
         #Make the EPUB
         try:
             make_epub(parsed_article,
-                      output_name,
-                      None,  # Does not use custom image path
-                      batch=True)
+                      outdirect=output_name,
+                      explicit_images=None,   # No explicit image path
+                      batch=False,
+                      config=config)
         except:
             error_file.write(item_path + '\n')
             traceback.print_exc(file=error_file)
@@ -189,7 +197,7 @@ def batch_input(args, config):
         #Running epubcheck on the output verifies the validity of the ePub,
         #requires a local installation of java and epubcheck.
         #if args.no_epubcheck:
-            #epubcheck('{0}.epub'.format(output_name))
+            #epubcheck('{0}.epub'.format(output_name), config)
     error_file.close()
 
 
@@ -222,9 +230,10 @@ class ParallelBatchProcess(multiprocessing.Process):
             output_name = os.path.join(utils.get_output_directory(self.args), raw_name)
             try:
                 make_epub(parsed_article,
-                          output_name,
-                          None,  # Does not use custom image path
-                          batch=True)
+                          outdirect=output_name,
+                          explicit_images=None,   # No explicit image path
+                          batch=False,
+                          config=config)
             except:
                 traceback.print_exc(file=self.error_file)
             #Cleanup output directory, keeps EPUB and log
@@ -232,7 +241,7 @@ class ParallelBatchProcess(multiprocessing.Process):
             #Running epubcheck on the output verifies the validity of the ePub,
             #requires a local installation of java and epubcheck.
             #if self.args.no_epubcheck:
-                #epubcheck('{0}.epub'.format(output_name))
+                #epubcheck('{0}.epub'.format(output_name), config)
             #Report completed task to the JoinableQueue
             self.task_queue.task_done()
         return
@@ -295,7 +304,7 @@ def zipped_input(args, config):
     pass
 
 
-def make_epub(document, outdirect, explicit_images, batch):
+def make_epub(document, outdirect, explicit_images, batch, config):
     """
     Encapsulates the primary processing work-flow. Before this method is
     called, pre-processing has occurred to define important directory and file
@@ -341,7 +350,7 @@ def make_epub(document, outdirect, explicit_images, batch):
     utils.epubZip(outdirect)
 
 
-def epubcheck(epubname):
+def epubcheck(epubname, config):
     """
     This method takes the name of an epub file as an argument. This name is
     the input for the java execution of a locally installed epubcheck-.jar. The
